# Records

Record operations create, extract or manipulate Timestreams of records.

## Record Methods

```{eval-rst}
.. currentmodule:: kaskada

.. autosummary::
   :toctree: ../apidocs/

    Timestream.col
    Timestream.select
    Timestream.remove
    Timestream.extend
    Timestream.record
    record
```